package VMOMI::HostUnresolvedVmfsExtentUnresolvedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
